@@ -14,16 +14,32 @@ class HelloWorld(w3bsite.views.Request):
 			base="requests/",
 		)
 	def view(self, request):
-		#if ..:
-		#	return self.error_response("Error: ...")
-		return self.success_response("Success ...", {"hello":"world"})
+		try:
+
+			# return response.
+			#if ..:
+			#	return self.error("Error: ...")
+			return self.success("Success ...", {"hello":"world"})
+
+		# catch error.
+		except Exception as e: return self._505(error=e)
+		
+		#
 
 # hello world compact.
 class HelloWorldSmall(w3bsite.views.Request):
 	def __init__(self):
 		w3bsite.views.Request.__init__(self, "requests/compact/", "hello-world")
 	def view(self, request):
-		return self.success_response("Success ...", {"hello":"world"})
+		try:
+
+			# return response.
+			return self.success("Success ...", {"hello":"world"})
+
+		# catch error.
+		except Exception as e: return self._505(error=e)
+		
+		#
 
 # the activate requests.
 urlpatterns = w3bsite.views.build_urls([
